==> cssadmin_1.0.2.tar.gz: cssadmin/admin/cssadmin_blocks.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// 
//*****************************************************************************/
require_once( dirname(dirname(__FILE__)) .'/init.php' );
require_once( XOOPS_ROOT_PATH .'/include/cp_header.php' );
require_once( XOOPS_ROOT_PATH .'/class/template.php' );
include_once( XOOPS_ROOT_PATH .'/modules/system/constants.php' ) ;
require_once( $mod_path .'/include/gtickets.php' );
require_once( $mod_path .'/include/cssadmin_buf.inc.php' );
include_once( $mod_path .'/include/mycssadmin_buf.inc.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/modinfo.php' );

// check access right (needs system_admin of BLOCK)
$sysperm_handler =& xoops_gethandler('groupperm');
if (!$sysperm_handler->checkRight('system_admin', XOOPS_SYSTEM_BLOCK, $xoopsUser->getGroups())) redirect_header( XOOPS_URL.'/user.php' , 1 , _NOPERM ) ;

// åν
unset( $_SESSION['cssadmin_op'] );

// URLμ
$current_url = $mod_url .'/admin/' .basename( __FILE__ );

// ƥץ졼Ȥ
$cssTpl =& new XoopsTpl;
$cssTpl->error_reporting = error_reporting();
$cssTpl->template_dir = $mod_path.'/admin/templates/';

//*****************************************************************************/
// ⥸塼μ
//*****************************************************************************/
$mid = !empty( $_GET['mid'] ) ? intval( $_GET['mid'] ) : 0;
$modules = array();
include( dirname(dirname(__FILE__)) .'/class/cssadmin_modules.class.php' );
$CssadminModules->setModuleList();
$modules = $CssadminModules->getModules();

$current_module = $modules[$mid];
$dirname = $current_module['dirname'];

//*****************************************************************************/
// ˥
//*****************************************************************************/
include( dirname(dirname(__FILE__)) .'/class/mycssadmin_display.class.php' );
$modules4disp = $CssadminDisplay->sanitizeArray4disp( $modules );

//*****************************************************************************/
// ɽ
//*****************************************************************************/
// ѥإåθƤӽФ
xoops_cp_header();
// ̾˥塼θƤӽФ
if( file_exists( './mymenu.php' ) ) include( './mymenu.php' );
// ⥸塼Υ
$cssTpl->assign( 'modules', $modules4disp );
// URLΥ
$cssTpl->assign( 'current_url', $current_url );
// ƥץ졼Ȥɽ
$cssTpl->display( 'cssadmin_blocks.html' );

//*****************************************************************************/
// mycssadminθƤӽФ
//*****************************************************************************/
// Ԥ
$action = $mod_url .'/admin/cssadmin_save.php';
// mycssadminɤ߹
include_once( dirname(__FILE__) .'/mycssadmin.php' );

//*****************************************************************************/
// λ
//*****************************************************************************/ 
// åؤγǼ
$_SESSION['cssadmin_blocks'] = $blocks;
$_SESSION['cssadmin_op'] = 'save_blocks_css';
// ѥեåθƤӽФ
xoops_cp_footer();

?>

==> cssadmin_1.0.4.tar.gz: cssadmin/admin/cssadmin_blocks.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// 
//*****************************************************************************/
require_once( dirname(dirname(__FILE__)) .'/init.php' );
require_once( XOOPS_ROOT_PATH .'/include/cp_header.php' );
require_once( XOOPS_ROOT_PATH .'/class/template.php' );
include_once( XOOPS_ROOT_PATH .'/modules/system/constants.php' ) ;
require_once( $mod_path .'/include/gtickets.php' );
require_once( $mod_path .'/include/cssadmin_buf.inc.php' );
require_once( $mod_path .'/include/mycssadmin.inc.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/modinfo.php' );

// check access right (needs system_admin of BLOCK)
$sysperm_handler =& xoops_gethandler('groupperm');
if (!$sysperm_handler->checkRight('system_admin', XOOPS_SYSTEM_BLOCK, $xoopsUser->getGroups())) redirect_header( XOOPS_URL.'/user.php' , 1 , _NOPERM ) ;

// åν
unset( $_SESSION['cssadmin_op'] );

// URLμ
$current_url = $mod_url .'/admin/' .basename( __FILE__ );

// ƥץ졼Ȥ
$cssTpl =& new XoopsTpl;
$cssTpl->error_reporting = error_reporting();
$cssTpl->template_dir = $mod_path.'/admin/templates/';

//*****************************************************************************/
// ⥸塼μ
//*****************************************************************************/
$mid = !empty( $_GET['mid'] ) ? intval( $_GET['mid'] ) : 0;
$modules = array();
include( dirname(dirname(__FILE__)) .'/class/cssadmin_modules.class.php' );
$CssadminModules->setModuleList();
$modules = $CssadminModules->getModules();

$current_module = $modules[$mid];
$dirname = $current_module['dirname'];

//*****************************************************************************/
// ˥
//*****************************************************************************/
include( dirname(dirname(__FILE__)) .'/class/mycssadmin.class.php' );
$modules4disp = $MyCssAdmin->sanitizeArray4disp( $modules );

//*****************************************************************************/
// ɽ
//*****************************************************************************/
// ѥإåθƤӽФ
xoops_cp_header();
// ̾˥塼θƤӽФ
if( file_exists( './mymenu.php' ) ) include( './mymenu.php' );
// ⥸塼Υ
$cssTpl->assign( 'modules', $modules4disp );
// URLΥ
$cssTpl->assign( 'current_url', $current_url );
// ƥץ졼Ȥɽ
$cssTpl->display( 'cssadmin_blocks.html' );

//*****************************************************************************/
// mycssadminθƤӽФ
//*****************************************************************************/
// Ԥ
$action = $mod_url .'/admin/cssadmin_save.php';
// mycssadminɤ߹
include_once( dirname(__FILE__) .'/mycssadmin.php' );

//*****************************************************************************/
// λ
//*****************************************************************************/ 
// åؤγǼ
$_SESSION['cssadmin_blocks'] = $blocks;
$_SESSION['cssadmin_op'] = 'save_blocks_css';
// ѥեåθƤӽФ
xoops_cp_footer();

?>
